package com.muyu.kvt.domain;

import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.kvt.domain.req.KvtEditReq;
import com.muyu.kvt.domain.req.KvtQueryReq;
import com.muyu.kvt.domain.req.KvtSaveReq;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;

import com.muyu.common.core.web.domain.BaseEntity;

/**
 * kvt
对象 kvt
 *
 * @author muyu
 * @date 2024-04-20
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("kvt")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "Kvt", description = "kvt")
public class Kvt extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 主键 */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "主键", value = "主键")
    private Long id;

    /** 接入源名称 */
    @Excel(name = "接入源名称")
    @ApiModelProperty(name = "接入源名称", value = "接入源名称")
    private String name;

    /** 数据来源系统名称 */
    @Excel(name = "数据来源系统名称")
    @ApiModelProperty(name = "数据来源系统名称", value = "数据来源系统名称")
    private String systemName;

    /** 数据接入类型 */
    @Excel(name = "数据接入类型")
    @ApiModelProperty(name = "数据接入类型", value = "数据接入类型")
    private Long type;

    /** 主机地址 */
    @Excel(name = "主机地址")
    @ApiModelProperty(name = "主机地址", value = "主机地址")
    private String host;

    /** 端口地址 */
    @Excel(name = "端口地址")
    @ApiModelProperty(name = "端口地址", value = "端口地址")
    private String port;

    /** 数据库名称 */
    @Excel(name = "数据库名称")
    @ApiModelProperty(name = "数据库名称", value = "数据库名称")
    private String databaseName;

    /** 数据连接参数 */
    @Excel(name = "数据连接参数")
    @ApiModelProperty(name = "数据连接参数", value = "数据连接参数")
    private String connectionParam;

    /** 初始连接数量 */
    @Excel(name = "初始连接数量")
    @ApiModelProperty(name = "初始连接数量", value = "初始连接数量")
    private Long initNum;

    /** 最大连接数量 */
    @Excel(name = "最大连接数量")
    @ApiModelProperty(name = "最大连接数量", value = "最大连接数量")
    private Long maxNum;

    /** 最大等待时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "最大等待时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "最大等待时间", value = "最大等待时间")
    private Date maxWaitTime;

    /** 最大等待次数 */
    @Excel(name = "最大等待次数")
    @ApiModelProperty(name = "最大等待次数", value = "最大等待次数")
    private Long maxWaitSize;

    /**
     * 用户名
     */
    @Excel(name = "用户名")
    @ApiModelProperty(name = "用户名",value = "用户名")
    private String username;
    /**
     * 密码
     */
    @Excel(name = "密码")
    @ApiModelProperty(name = "密码",value = "密码")
    private String password;




    /**
    * 查询构造器
    */
    public static Kvt queryBuild( KvtQueryReq kvtQueryReq){
        return Kvt.builder()
                .name(kvtQueryReq.getName())
                .systemName(kvtQueryReq.getSystemName())
                .type(kvtQueryReq.getType())
                .host(kvtQueryReq.getHost())
                .port(kvtQueryReq.getPort())
                .databaseName(kvtQueryReq.getDatabaseName())
                .connectionParam(kvtQueryReq.getConnectionParam())
                .initNum(kvtQueryReq.getInitNum())
                .maxNum(kvtQueryReq.getMaxNum())
                .maxWaitTime(kvtQueryReq.getMaxWaitTime())
                .maxWaitSize(kvtQueryReq.getMaxWaitSize())
                .username(kvtQueryReq.getUsername())
                .password(kvtQueryReq.getPassword())
                .build();
    }

    /**
    * 添加构造器
    */
    public static Kvt saveBuild(KvtSaveReq kvtSaveReq){
        return Kvt.builder()
                .name(kvtSaveReq.getName())
                .systemName(kvtSaveReq.getSystemName())
                .type(kvtSaveReq.getType())
                .host(kvtSaveReq.getHost())
                .port(kvtSaveReq.getPort())
                .databaseName(kvtSaveReq.getDatabaseName())
                .connectionParam(kvtSaveReq.getConnectionParam())
                .initNum(kvtSaveReq.getInitNum())
                .maxNum(kvtSaveReq.getMaxNum())
                .maxWaitTime(kvtSaveReq.getMaxWaitTime())
                .maxWaitSize(kvtSaveReq.getMaxWaitSize())
                .username(kvtSaveReq.getUsername())
                .password(kvtSaveReq.getPassword())
                .build();
    }

    /**
    * 修改构造器
    */
    public static Kvt editBuild(Long id, KvtEditReq kvtEditReq){
        return Kvt.builder()
            .id(id)
                .name(kvtEditReq.getName())
                .systemName(kvtEditReq.getSystemName())
                .type(kvtEditReq.getType())
                .host(kvtEditReq.getHost())
                .port(kvtEditReq.getPort())
                .databaseName(kvtEditReq.getDatabaseName())
                .connectionParam(kvtEditReq.getConnectionParam())
                .initNum(kvtEditReq.getInitNum())
                .maxNum(kvtEditReq.getMaxNum())
                .maxWaitTime(kvtEditReq.getMaxWaitTime())
                .maxWaitSize(kvtEditReq.getMaxWaitSize())
                .username(kvtEditReq.getUsername())
                .password(kvtEditReq.getPassword())
                .build();
    }

}
