package com.muyu.kvt.controller;

import java.sql.SQLException;
import java.util.List;


import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.system.domain.SysDept;
import com.muyu.kvt.dataStructure.OverallDataStructure;
import com.muyu.kvt.datadisplay.DataDisplay;
import com.muyu.kvt.dictionary.Diction;
import com.muyu.kvt.dictionary.DictionaryType;
import com.muyu.kvt.dictionary.Dictionaryy;
import com.muyu.kvt.domain.*;
import com.muyu.kvt.domain.req.KvtEditReq;
import com.muyu.kvt.domain.req.KvtQueryReq;
import com.muyu.kvt.domain.req.KvtSaveReq;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import com.muyu.kvt.service.KvtService;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;

/**
 * kvt
Controller
 *
 * @author muyu
 * @date 2024-04-20
 */
@Api(tags = "kvt")
@RestController
@RequestMapping("/kvt")
public class KvtController extends BaseController {
    @Autowired
    private KvtService kvtService;

    /**
     * 查询kvt列表
     */
    @ApiOperation("获取kvt列表")
    @RequiresPermissions("kvt:kvt:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Kvt>> list(KvtQueryReq kvtQueryReq) {
        startPage();
        List<Kvt> list = kvtService.list(Kvt.queryBuild(kvtQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出kvt列表
     */
    @ApiOperation("导出kvt列表")
    @RequiresPermissions("kvt:kvt:export")
    @Log(title = "kvt", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Kvt kvt) {
        List<Kvt> list = kvtService.list(kvt);
        ExcelUtil<Kvt> util = new ExcelUtil<Kvt>(Kvt.class);
        util.exportExcel(response, list, "kvt数据");
    }

    /**
     * 获取kvt详细信息
     */
    @ApiOperation("获取kvt详细信息")
    @RequiresPermissions("kvt:kvt:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Kvt> getInfo(@PathVariable("id") Long id) {
        return Result.success(kvtService.getById(id));
    }

    /**
     * 新增kvt
     */
    @RequiresPermissions("kvt:kvt:add")
    @Log(title = "kvt ", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增kvt ")
    public Result<String> add(@RequestBody KvtSaveReq kvtSaveReq) {
        return toAjax(kvtService.save(Kvt.saveBuild(kvtSaveReq)));
    }

    /**
     * 修改kvt

     */
    @RequiresPermissions("kvt:kvt:edit")
    @Log(title = "kvt ", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改kvt")
    public Result<String> edit(@PathVariable Long id, @RequestBody KvtEditReq kvtEditReq) {
        return toAjax(kvtService.updateById(Kvt.editBuild(id,kvtEditReq)));
    }

    /**
     * 删除kvt

     */
    @RequiresPermissions("kvt:kvt:remove")
    @Log(title = "kvt ", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除kvt")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(kvtService.removeBatchByIds(ids));
    }

    /**
     * 测试连接
     */
    @PostMapping("/connectionTest")
    public Result connectionTest(@RequestBody Kvt kvt) throws SQLException, ClassNotFoundException {
       boolean test= kvtService.connectionTest(kvt);
        if (test){
            return Result.success("测试成功");
        }else {
            return Result.error("测试失败");
        }
    }


    /**
     * 数据库类型
     * @return
     */
    @PostMapping("/dataTypeList")
    public Result<List<DataType>> dataTypeList(){
        List<DataType> dataTypeList=kvtService.dataTypeList();
        return  Result.success(dataTypeList);

    }

    /**
     *
     * @param databaseName 数据库名称
     * @return
     */

    @PostMapping("/selectDataAuthorization")
    public Result selectDataAuthorization (@RequestParam String databaseName){
             kvtService.selectDataAuthorization(databaseName);
        return Result.success();

    }

    //查询数据
    @PostMapping("/selectDataSource")
    public Result<List<AssetStructureList>> assetStructureList(){
       List<AssetStructureList> assetStructureLists= kvtService.assetStructureList();
      return Result.success(assetStructureLists);
    }

    //部門
    @PostMapping("/selectDepartment")
    public Result<List<ChildrenList>> selectDepartment(@RequestParam String databaseName){
       List<ChildrenList> list= kvtService.selectDepartment(databaseName);
        return Result.success(list);
    }

    @PostMapping("/selectDataStructure")
    public Result<List<DataStructure>>  selectDataStructure(@RequestParam String databaseName,String name){
      return  Result.success();
    }
    @PostMapping("/selectDataStur")
    public Result<List<DataStructure>>  selectDataStur(@RequestParam String tableName){
       List<DataStructure> structureList=  kvtService.selectDataStur(tableName);
      return  Result.success(structureList);
    }

    @PostMapping("/selectChild")
    public Result<Child> selectChild(@RequestParam String tableName){
      Child child=  kvtService.selectChild(tableName);
      return  Result.success(child);
    }
     //查询数据结构
    @PostMapping("/selectChildAll")
    public Result<List<DataStructure>> selectChildAll(){
        List<DataStructure> childList=kvtService.selectChildAll();
        return Result.success(childList);
    }

    //查询所有部门
    @PostMapping("/selectDept")
    public Result<List<SysDept>> deptList(){
       List<SysDept> list=  kvtService.deptList();
        return Result.success(list);
    }

    //查询字典
    @PostMapping("/selectDictionaryy")
    public Result<List<Diction>> selectDictionaryy( Integer id){
        List<Diction> list= kvtService.selectDictionaryy(id);
        return Result.success(list);
     }



     //同步数据添加到数据库
    @PostMapping("/synchronizationAdd")
    public Result synchronizationAdd(@RequestBody Kvt kvt) throws SQLException, ClassNotFoundException {
        return  kvtService.synchronizationAdd(kvt);
    }
     //添加字典
    @PostMapping("/dictionaryTypeAdd")
    public Result dictionaryTypeAdd(@RequestBody Dictionaryy dictionaryy) {
        kvtService.dictionaryTypeAdd(dictionaryy);
        return Result.success("添加成功");

    }
    //添加字典类型
    @PostMapping("/dictionTypeAdd")
    public Result dictionTypeAdd(@RequestBody DictionaryType dictionaryType) {
        kvtService.dictionTypeAdd(dictionaryType);
        return Result.success("添加成功");

    }
    //查询字典是否存在
    @PostMapping("/selectDictionaryTypeId")
    public Result selectDictionaryTypeId(@RequestBody Dictionaryy dictionaryy) {
        Dictionaryy dictionaryType = kvtService.selectDictionaryTypeId(dictionaryy.getId());
        if (dictionaryType !=null ){
            kvtService.delDictionaryTypeId(dictionaryy);
            return Result.success("修改成功");
        }
        kvtService.dictionaryTypeAdd(dictionaryy);
        return Result.success("添加成功");

    }
    /**
     * 修改数据模型(字典)
     */
    @PostMapping("utilAssetModel")
    public Result utilAssetModel(@RequestBody DataStructure dataStructure){
        kvtService.utilAssetModel(dataStructure);
        return Result.success("修改成功");
    }

    //查询数据结构数量
    @PostMapping("/OverallDataStructure")
    public Result<OverallDataStructure> selectOver(){
        return kvtService.OverallDataStructure();
    }


    //查询资产展示
    @PostMapping("/selectDataDisplay")
    public Result<List<DataDisplay>> listResult(){
        List<DataDisplay> list= kvtService.listResult();
        return Result.success(list);
    }
    //根据库名查询资产展示
    @PostMapping("/selectDataDisplayName")
    public Result<List<DataDisplay>> listResult(String name ){
        List<DataDisplay> list= kvtService.selectDataDisplayName(name);
        return Result.success(list);
    }
}
