package com.muyu.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.system.domain.AsUserDept;
import com.muyu.system.domain.resp.AsUserDeotNumResponse;
import com.muyu.system.service.service.IAsUserDeptService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 用户与部门中间Controller
 *
 * @author muyu
 * @date 2024-04-14
 */
@RestController
@RequestMapping("/userDept")
public class AsUserDeptController extends BaseController
{
    @Autowired
    private IAsUserDeptService asUserDeptService;

    /**
     * 查询用户与部门中间列表
     */
    @RequiresPermissions("product:dept:list")
    @GetMapping("/list")
    public Result<TableDataInfo<AsUserDept>> list(AsUserDept asUserDept)
    {
        startPage();
        List<AsUserDept> list = asUserDeptService.selectAsUserDeptList(asUserDept);
        return getDataTable(list);
    }

    /**
     * 导出用户与部门中间列表
     */
    @RequiresPermissions("product:dept:export")
    @Log(title = "用户与部门中间", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AsUserDept asUserDept)
    {
        List<AsUserDept> list = asUserDeptService.selectAsUserDeptList(asUserDept);
        ExcelUtil<AsUserDept> util = new ExcelUtil<AsUserDept>(AsUserDept.class);
        util.exportExcel(response, list, "用户与部门中间数据");
    }

    /**
     * 获取用户与部门中间详细信息
     */
    @RequiresPermissions("product:dept:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(asUserDeptService.selectAsUserDeptById(id));
    }

    /**
     * 新增用户与部门中间
     */
    @RequiresPermissions("product:dept:add")
    @Log(title = "用户与部门中间", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody AsUserDept asUserDept)
    {
        return toAjax(asUserDeptService.insertAsUserDept(asUserDept));
    }

    /**
     * 修改用户与部门中间
     */
    @RequiresPermissions("product:dept:edit")
    @Log(title = "用户与部门中间", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody AsUserDept asUserDept)
    {
        return toAjax(asUserDeptService.updateAsUserDept(asUserDept));
    }

    /**
     * 删除用户与部门中间
     */
    @RequiresPermissions("product:dept:remove")
    @Log(title = "用户与部门中间", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(asUserDeptService.deleteAsUserDeptByIds(ids));
    }

    @GetMapping("/UpdateAsUserDept")
    public Result list(@RequestParam("id") Long id)
    {
        return asUserDeptService.updateAsUserDeptRead(id);
    }

    @GetMapping("/GetNum")
    public Result<AsUserDeotNumResponse> getNum(@RequestParam("noticeId") Long noticeId)
    {
        return asUserDeptService.getNum(noticeId);
    }
}
