package com.muyu.system.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.domain.Result;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.system.domain.AsUserDept;
import com.muyu.system.domain.SysNotice;
import com.muyu.system.domain.req.SysNoticeRequest;
import com.muyu.system.domain.resp.SysNoticeResponse;
import com.muyu.system.mapper.AsUserDeptMapper;
import com.muyu.system.mapper.SysNoticeMapper;
import com.muyu.system.mapper.SysUserMapper;
import com.muyu.system.service.SysNoticeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 公告 服务层实现
 *
 * @author muyu
 */
@Service
public class SysNoticeServiceImpl extends ServiceImpl<SysNoticeMapper, SysNotice> implements SysNoticeService {
    @Autowired
    private SysNoticeMapper noticeMapper;

    @Autowired
    private SysUserMapper sysUserMapper;
    @Autowired
    private AsUserDeptMapper asUserDeptMapper;
    /**
     * 查询公告信息
     *
     * @param noticeId 公告ID
     *
     * @return 公告信息
     */
    @Override
    public SysNotice selectNoticeById (Long noticeId) {
        return noticeMapper.selectNoticeById(noticeId);
    }

    /**
     * 查询公告列表
     *
     * @param notice 公告信息
     *
     * @return 公告集合
     */
    @Override
    public List<SysNotice> selectNoticeList(SysNotice notice) {
        return noticeMapper.selectNoticeList(notice);
    }


    public List<AsUserDept> handleList(List<Long> personnelList ,List<List<Long>> sectionList,Long noticeId){
        ArrayList<Long> longs = new ArrayList<>();
        if (sectionList!=null && sectionList.size()!=0){
            sectionList.stream()
                    .map(section -> {
                        for (Long aLong : section) {
                            longs.add(aLong);
                        }
                        return null;
                    }).collect(Collectors.toList());
            List<Long> sectionIds =longs.stream().distinct().toList();
           List<Long> userIds= sysUserMapper.selectDtptUser(sectionIds);
           if (userIds !=null){
               personnelList.addAll(userIds);
           }
        }
        personnelList= personnelList.stream().distinct().toList();
        System.out.println(personnelList);
        List<AsUserDept> asUserDepts = personnelList.stream()
                .map(personnel -> {
                    AsUserDept asUserDept = new AsUserDept();
                    asUserDept.setNoticeId(personnel);
                    asUserDept.setNoticeId(noticeId);
                    asUserDept.setCreateBy(SecurityUtils.getUsername());
                    asUserDept.setCreateTime(new Date());
                    return asUserDept;
                }).toList();
        return asUserDepts;
    }
    /**
     * 新增公告
     *
     * @param notice 公告信息
     *
     * @return 结果
     */
    @Override
    @Transactional
    public int insertNotice (SysNotice notice) {
        int i = noticeMapper.insertNotice(notice);
        if (notice.getNoticeType().equals("1")){
            Long noticeId = notice.getNoticeId();
            List<Long> personnnelList = notice.getPersonnelList();
            List<List<Long>> sectionList = notice.getSectionList();
            List<AsUserDept> asUserDepts = handleList(personnnelList, sectionList, noticeId);
            asUserDeptMapper.insertBachAsUserDept(asUserDepts);
        }else {
           List<Long> userIds =  noticeMapper.selectUser();
            List<AsUserDept> asUserDepts = userIds.stream().map(id -> {
                AsUserDept asUserDept = new AsUserDept();
                asUserDept.setNoticeId(notice.getNoticeId());
                asUserDept.setCreateTime(new Date());
                asUserDept.setUserId(id);
                asUserDept.setCreateBy(SecurityUtils.getUsername());
                return asUserDept;
            }).toList();
            asUserDeptMapper.insertBachAsUserDept(asUserDepts);
        }
        return i;
    }

    /**
     * 修改公告
     *
     * @param notice 公告信息
     *
     * @return 结果
     */
    @Override
    public int updateNotice (SysNotice notice) {
        return noticeMapper.updateNotice(notice);
    }

    /**
     * 删除公告对象
     *
     * @param noticeId 公告ID
     *
     * @return 结果
     */
    @Override
    public int deleteNoticeById (Long noticeId) {
        return noticeMapper.deleteNoticeById(noticeId);
    }

    /**
     * 批量删除公告信息
     *
     * @param noticeIds 需要删除的公告ID
     *
     * @return 结果
     */
    @Override
    public int deleteNoticeByIds (Long[] noticeIds) {
        return noticeMapper.deleteNoticeByIds(noticeIds);
    }

    @Override
    public Result<List<SysNoticeResponse>> getNoticeList(SysNoticeRequest sysNoticeRequest) {
          sysNoticeRequest.setNoticeId(
                  SecurityUtils.getUserId()
          );
         List<SysNoticeResponse> noticeList=   noticeMapper.getNoticeList(sysNoticeRequest);
        return Result.success(noticeList);
    }
}
