package com.muyu.system.service.service.impl;


import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.system.domain.AsUserDept;
import com.muyu.system.domain.resp.AsUserDeotNumResponse;
import com.muyu.system.mapper.AsUserDeptMapper;
import com.muyu.system.service.service.IAsUserDeptService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用户与部门中间Service业务层处理
 *
 * @author muyu
 * @date 2024-04-14
 */
@Service
public class AsUserDeptServiceImpl implements IAsUserDeptService
{
    @Autowired
    private AsUserDeptMapper asUserDeptMapper;

    /**
     * 查询用户与部门中间
     *
     * @param id 用户与部门中间主键
     * @return 用户与部门中间
     */
    @Override
    public AsUserDept selectAsUserDeptById(Long id)
    {
        return asUserDeptMapper.selectAsUserDeptById(id);
    }

    /**
     * 查询用户与部门中间列表
     *
     * @param asUserDept 用户与部门中间
     * @return 用户与部门中间
     */
    @Override
    public List<AsUserDept> selectAsUserDeptList(AsUserDept asUserDept)
    {
        return asUserDeptMapper.selectAsUserDeptList(asUserDept);
    }

    /**
     * 新增用户与部门中间
     *
     * @param asUserDept 用户与部门中间
     * @return 结果
     */
    @Override
    public int insertAsUserDept(AsUserDept asUserDept)
    {
        asUserDept.setCreateTime(DateUtils.getNowDate());
        return asUserDeptMapper.insertAsUserDept(asUserDept);
    }

    /**
     * 修改用户与部门中间
     *
     * @param asUserDept 用户与部门中间
     * @return 结果
     */
    @Override
    public int updateAsUserDept(AsUserDept asUserDept)
    {
        asUserDept.setUpdateTime(DateUtils.getNowDate());
        return asUserDeptMapper.updateAsUserDept(asUserDept);
    }

    /**
     * 批量删除用户与部门中间
     *
     * @param ids 需要删除的用户与部门中间主键
     * @return 结果
     */
    @Override
    public int deleteAsUserDeptByIds(Long[] ids)
    {
        return asUserDeptMapper.deleteAsUserDeptByIds(ids);
    }

    /**
     * 删除用户与部门中间信息
     *
     * @param id 用户与部门中间主键
     * @return 结果
     */
    @Override
    public int deleteAsUserDeptById(Long id)
    {
        return asUserDeptMapper.deleteAsUserDeptById(id);
    }

    @Override
    public Result updateAsUserDeptRead(Long id) {
        asUserDeptMapper.updateAsUserDeptRead(id);
        return Result.success();
    }

    @Override
    public Result<AsUserDeotNumResponse> getNum(Long noticeId) {
        Long num =    asUserDeptMapper.selectAsUserDeptNum(noticeId);
        Long readNum = asUserDeptMapper.selectAsUserDeptReadNum(noticeId);
        long noreadNum= num-readNum;
        return Result.success(AsUserDeotNumResponse.builder()
                .num(num)
                .readNum(readNum)
                .noReadNum(noreadNum)
                .build());
    }
}
